% Convolution: The process of applying a filter to an image is usually referred to as convolution
% Here we filter the image with a high pass filter (or image derivatives)

clear all; close all

ima = imread('D26.jpg');
%ima = imread('zebra.jpg');

ima = mean(ima,3);

subplot(2,2,1)
imagesc(ima)
colormap(gray(256))


%% Convolution with a high pass kernel

hk=[-1 0 1]; % or hk = [-1 1] for a sharper filter that keeps vertical contours
imasharp=convn(ima,hk);
subplot(2,2,2)
imagesc(imasharp);
%image(uint8(imasharp));

% Same kernel, with opposite signs (to run on zebra)
hk=[1 0 -1]; % 
imasharpI=convn(ima,hk);
subplot(2,2,4)
imagesc(imasharpI);

%% Exercice: Convolve the image with a kernel that keeps the horizontal contours

hkH=hk'; % transpose the kernel or hkH=[1;-1];
imasharp2=convn(ima,hkH);
subplot(2,2,3)
imagesc(imasharp2);

%% Exercice: Convolve the image with a kernel that keeps the diagonals

hkD=[-1 1 ; 1 -1]
imasharp3=convn(ima,hkD);
subplot(2,2,4)
imagesc(imasharp3);

text = imread('texturediag.jpg');
text = mean(text,3);
imasharp4=convn(text,hkD);

figure(2)
subplot(2,2,1)
imagesc(text)
colormap(gray(256))
subplot(2,2,2)
imagesc(imasharp4);


%% Exercice: Convolve the image with another kernel (filter, mask) called
%% Laplacien filter


ima = imread('moon.tif');


hkL=[0 1 0 ; 1 -4 1 ; 0 1 0]
imasharpL=convn(ima,hkL);
figure(2)
subplot(2,2,1)
image(imasharpL);colormap(gray(256))

hkL2=[1 1 1 ; 1 -8 1 ; 1 1 1]
imasharpL2=convn(ima,hkL2);
figure(2)
subplot(2,2,2)
image(imasharpL2);colormap(gray(256))


