
% Intensity Transformation from DIPUM2 Chapter 3
% Image processing toolbox function: 
% g = imadjust(f, [low_in high_in], [low_out high_out], gamma)
% Values are specified between [0 1]
% You musr run pieces within a section at a time

%% Reading the image


clear all; close all

ima = imread('Fig0303(a).tif');

figure
subplot(2,3,1)
image(ima); 
colormap(gray(256)); axis('square'); axis('off')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% PART I: INTENSITY TRANSFORMATION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Creating a negative version using imadjust

imaNegative = imadjust(ima,[0 1], [1 0]);
subplot(2,3,2)
image(imaNegative); axis('square'); axis('off')

% Alternatively use function "imcomplement"
% imaNegative = imcomplement(ima);


%% To highlight an intensity band: expend gray scale interval

imaIntensity = imadjust(ima, [0.5 0.75], [0 1]);
subplot(2,3,3)
image(imaIntensity); axis('square'); axis('off')

imaIntensity2 = imadjust(ima, [ ], [ ], 2); % last term is gamma
subplot(2,3,4)
image(imaIntensity2); axis('square'); axis('off')

%% Image histogram representation

figure
subplot(2,3,1)
image(ima); colormap(gray(256));  axis('off')
subplot(2,3,2)
imhist(ima)
subplot(2,3,3)
imhist(ima,25)
subplot(2,3,4)
h = imhist(ima,25);
horz = linspace(0, 255, 25);
stem(horz, h, 'fill')
axis([0 255 0 60000])
set(gca, 'xtick', 0:50:255)
set(gca, 'ytick', 0:20000:60000)
subplot(2,3,5)
hc= imhist(ima);
plot(hc);
axis([0 255 0 15000])
set(gca, 'xtick', 0:50:255)
set(gca, 'ytick', 0:20000:15000)



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% PART II: HISTOGRAM EQUALIZATION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ima = imread('Fig0308(a).tif');

figure
subplot(2,2,1)
imshow(ima); % Note: you can also use here image(ima)
colormap(gray(256)); axis('square'); axis('off')

subplot(2,2,2)
imhist(ima)
ylim('auto');

subplot(2,2,3)
g = histeq(ima,256);
imshow(g);

subplot(2,2,4)
imhist(g)
ylim('auto');

