
%% Intensity scaling
% Make all gray level images of a directory with a mean of 128, by rescaling
% the gray levels (do not equalize the image histogram)
% This code works for images of squared size, and all images must be of the
% same size (e.g. 256 x 256 pixels).

clear all;
folder = 'original';
folderBW = 'transformed';
list = dir([folder '/*.jpg']); % make a list of all files that end with ".jpg" for instance

for i=1:(size(list,1));
    i    
    nameima=list(i).name;
    ima=imread([folder '/' nameima]);
    [sx,sy,c]=size(ima);
    ima=mean(ima,3); % Put a color image in black and white;
    imaO=double(ima); % save the original black and white image for display later
    ima=double(ima); % An image onto which we are going to apply any type of transformation needs to be put in "double" format
    ima=ima(:); % tranform the 2 d image in a 1d vector of intensity values
    
    ima = (ima - min(ima(:))); % remove the minimun intensity value
    ima = 255 * ima / max(ima(:)); % divide by the maximum intensity value
    
    meangray=mean(ima);
    
    for n=1:size(ima,1)
        ima(n,:) = (ima(n,:)-(meangray-128)); % make the image with a mean intensity of 128
    end
    
    ima=reshape(ima,sx,sx); % put back the 1d vector into a 2d image
    
    j = find(ima<0); ima(j) = 0;
    j = find(ima>255); ima(j) = 255;
    
    figure
    subplot(1,2,1); image(imaO); colormap(gray(256)); axis('square'); axis('off')
    subplot(1,2,2); image(ima); axis('square'); axis('off')
    imwrite(uint8(ima),[folderBW '\' nameima],'jpeg','quality',100);
end

